//
//  ViewController.swift
//  ar
//
//  Created by kunii on 2018/08/09.
//  Copyright © 2018年 Takahiro Kunii. All rights reserved.
//

import UIKit
import ARKit

class ViewController: UIViewController {

    // ARシーンを表示する
    var sceneView:ARSCNView!
    
    override func viewDidLoad() {
        super.viewDidLoad()

        // ARシーンを表示するビューの作成とself.view小画面としての登録
        sceneView = ARSCNView(frame: self.view.bounds)
        sceneView.autoresizingMask = [.flexibleWidth, .flexibleHeight]
        self.view.addSubview(sceneView)
        
        // 3D文字列を管理する仮想シーン環境
        let scene = SCNScene()
        
        // 3D文字列（こんにちはAR）の作成と仮想シーン環境への登録
        let geometry = SCNText(string: "こんにちはAR", extrusionDepth: 3)
        let node = SCNNode(geometry:geometry)

        // 横の大きさを0.5mにする
        let scale = 1 / (geometry.boundingSphere.radius * 2) * 0.5
        node.scale = SCNVector3(x:scale, y:scale, z:scale)
        
        // 配置と登録　前方0.5mの空中に配置
        node.position = SCNVector3(-0.25, 0.1, -0.5)
        scene.rootNode.addChildNode(node)
        
        // ARシーンを表示するビューへの仮想シーン環境の登録
        sceneView.scene = scene

        //  光源ノードを作り3D仮想空間のルートノードに追加
        let lightNode = SCNNode()
        let light = SCNLight()
        lightNode.light = light
        scene.rootNode.addChildNode(lightNode)
        
        //  拡散反射色の設定
        geometry.firstMaterial?.diffuse.contents = UIColor(hue: 0.9, saturation: 1, brightness: 1, alpha: 1)
        
        //  環境光の追加
        //        let ambientLightNode = SCNNode()
        //        let ambientLight = SCNLight()
        //        ambientLight.type = .ambient
        //        ambientLight.color = UIColor(white: 0.5, alpha: 1)
        //        ambientLightNode.light = ambientLight
        //        scene.rootNode.addChildNode(ambientLightNode)
    }

    override func didReceiveMemoryWarning() {
        super.didReceiveMemoryWarning()
        // Dispose of any resources that can be recreated.
    }

    override func viewWillAppear(_ animated: Bool) {
        super.viewWillAppear(animated)
        
        // ARセッションの初期設定
        let configuration = ARWorldTrackingConfiguration()
        
        // ARセッション開始
        sceneView.session.run(configuration)
    }
    
    override func viewWillDisappear(_ animated: Bool) {
        super.viewWillDisappear(animated)
        
        // セッション停止
        sceneView.session.pause()
    }
}

